==> information-view-api-0.2-sources.jar: org/odpi/openmetadata/accessservices/informationview/events/ReportColumn.java <==
/* SPDX-License-Identifier: Apache-2.0 */
package org.odpi.openmetadata.accessservices.informationview.events;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

@JsonAutoDetect(getterVisibility = PUBLIC_ONLY, setterVisibility = PUBLIC_ONLY, fieldVisibility = NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class ReportColumn {


    private String attributeName;
    private String aggregation;
    private String sectionName;
    private String formula;
    private DatabaseColumnReference realColumn;

    public String getAttributeName() {
        return attributeName;
    }

    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public String getAggregation() {
        return aggregation;
    }

    public void setAggregation(String aggregation) {
        this.aggregation = aggregation;
    }

    public String getSectionName() {
        return sectionName;
    }

    public void setSectionName(String sectionName) {
        this.sectionName = sectionName;
    }

    public String getFormula() {
        return formula;
    }

    public void setFormula(String formula) {
        this.formula = formula;
    }

    public DatabaseColumnReference getRealColumn() {
        return realColumn;
    }

    public void setRealColumn(DatabaseColumnReference realColumn) {
        this.realColumn = realColumn;
    }


    @Override
    public String toString() {
        return "ReportColumn{" +
                "attributeName='" + attributeName + '\'' +
                ", aggregation='" + aggregation + '\'' +
                ", sectionName='" + sectionName + '\'' +
                ", formula='" + formula + '\'' +
                ", realColumn=" + realColumn +
                '}';
    }
}

==> information-view-api-1.0-sources.jar: org/odpi/openmetadata/accessservices/informationview/events/ReportColumn.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.informationview.events;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.List;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

@JsonAutoDetect(getterVisibility = PUBLIC_ONLY, setterVisibility = PUBLIC_ONLY, fieldVisibility = NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class ReportColumn extends ReportElement {

    private String aggregation;
    private String formula;
    private List<Source> sources;
    private BusinessTerm businessTerm;

    public String getAggregation() {
        return aggregation;
    }

    public void setAggregation(String aggregation) {
        this.aggregation = aggregation;
    }

    public String getFormula() {
        return formula;
    }

    public void setFormula(String formula) {
        this.formula = formula;
    }

    public List<Source> getSources() {
        return sources;
    }

    public void setSources(List<Source> sources) {
        this.sources = sources;
    }

    public BusinessTerm getBusinessTerm() {
        return businessTerm;
    }

    public void setBusinessTerm(BusinessTerm businessTerm) {
        this.businessTerm = businessTerm;
    }

    @Override
    public String toString() {
        return "ReportColumn{" +
                "aggregation='" + aggregation + '\'' +
                ", formula='" + formula + '\'' +
                ", sources=" + sources +
                ", businessTerm=" + businessTerm +
                ", name='" + name + '\'' +
                '}';
    }
}
